package tech.easyflow.ai.service;

import com.mybatisflex.core.service.IService;
import org.springframework.web.multipart.MultipartFile;
import tech.easyflow.ai.entity.FaqItem;
import tech.easyflow.ai.vo.FaqImportResultVo;

import java.io.OutputStream;
import java.math.BigInteger;

public interface FaqItemService extends IService<FaqItem> {

    boolean saveFaqItem(FaqItem entity);

    boolean updateFaqItem(FaqItem entity);

    boolean removeFaqItem(BigInteger id);

    FaqImportResultVo importFromExcel(BigInteger collectionId, MultipartFile file);

    void exportToExcel(BigInteger collectionId, OutputStream outputStream);

    void writeImportTemplate(OutputStream outputStream);
}
